---
title: teedoc
keywords: teedoc, markdown, jupyter notebook, html, document generation, alternative gitbook, website generation, static website, document website generation, multiple documents
desc: teedoc, convert markdown or jupyter notbook into html static webpage
---




<div id="home_page">
    <div>
        <h1><span>teedoc</span></h1>
        <h3>Concise and comprehensive website/document generator</h3>
    </div>
    <div id="big_btn_wrapper">
        <div class="big_btn">
            <a href="/get_started/zh/">Get started</a>
        </div>
    </div>

</div>
